==> vtk-8.1.1-1-aarch64.pkg.tar.xz: vtk/vtkStaticPointLocator.java <==
// java wrapper for vtkStaticPointLocator object
//

package vtk;
import vtk.*;

public class vtkStaticPointLocator extends vtkAbstractPointLocator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPointsPerBucket_2(int id0);
  public void SetNumberOfPointsPerBucket(int id0)
    { SetNumberOfPointsPerBucket_2(id0); }

  private native int GetNumberOfPointsPerBucketMinValue_3();
  public int GetNumberOfPointsPerBucketMinValue()
    { return GetNumberOfPointsPerBucketMinValue_3(); }

  private native int GetNumberOfPointsPerBucketMaxValue_4();
  public int GetNumberOfPointsPerBucketMaxValue()
    { return GetNumberOfPointsPerBucketMaxValue_4(); }

  private native int GetNumberOfPointsPerBucket_5();
  public int GetNumberOfPointsPerBucket()
    { return GetNumberOfPointsPerBucket_5(); }

  private native void SetDivisions_6(int id0,int id1,int id2);
  public void SetDivisions(int id0,int id1,int id2)
    { SetDivisions_6(id0,id1,id2); }

  private native void SetDivisions_7(int id0[]);
  public void SetDivisions(int id0[])
    { SetDivisions_7(id0); }

  private native int[]  GetDivisions_8();
  public int[]  GetDivisions()
    { return GetDivisions_8(); }

  private native int FindClosestPoint_9(double id0[]);
  public int FindClosestPoint(double id0[])
    { return FindClosestPoint_9(id0); }

  private native void FindClosestNPoints_10(int id0,double id1[],vtkIdList id2);
  public void FindClosestNPoints(int id0,double id1[],vtkIdList id2)
    { FindClosestNPoints_10(id0,id1,id2); }

  private native void FindPointsWithinRadius_11(double id0,double id1[],vtkIdList id2);
  public void FindPointsWithinRadius(double id0,double id1[],vtkIdList id2)
    { FindPointsWithinRadius_11(id0,id1,id2); }

  private native void Initialize_12();
  public void Initialize()
    { Initialize_12(); }

  private native void FreeSearchStructure_13();
  public void FreeSearchStructure()
    { FreeSearchStructure_13(); }

  private native void BuildLocator_14();
  public void BuildLocator()
    { BuildLocator_14(); }

  private native void GenerateRepresentation_15(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_15(id0,id1); }

  private native int GetNumberOfPointsInBucket_16(int id0);
  public int GetNumberOfPointsInBucket(int id0)
    { return GetNumberOfPointsInBucket_16(id0); }

  private native void GetBucketIds_17(int id0,vtkIdList id1);
  public void GetBucketIds(int id0,vtkIdList id1)
    { GetBucketIds_17(id0,id1); }

  private native void SetMaxNumberOfBuckets_18(int id0);
  public void SetMaxNumberOfBuckets(int id0)
    { SetMaxNumberOfBuckets_18(id0); }

  private native int GetMaxNumberOfBucketsMinValue_19();
  public int GetMaxNumberOfBucketsMinValue()
    { return GetMaxNumberOfBucketsMinValue_19(); }

  private native int GetMaxNumberOfBucketsMaxValue_20();
  public int GetMaxNumberOfBucketsMaxValue()
    { return GetMaxNumberOfBucketsMaxValue_20(); }

  private native int GetMaxNumberOfBuckets_21();
  public int GetMaxNumberOfBuckets()
    { return GetMaxNumberOfBuckets_21(); }

  private native boolean GetLargeIds_22();
  public boolean GetLargeIds()
    { return GetLargeIds_22(); }

  private native int FindClosestPoint_23(double id0,double id1,double id2);
  public int FindClosestPoint(double id0,double id1,double id2)
    { return FindClosestPoint_23(id0,id1,id2); }

  private native void FindClosestNPoints_24(int id0,double id1,double id2,double id3,vtkIdList id4);
  public void FindClosestNPoints(int id0,double id1,double id2,double id3,vtkIdList id4)
    { FindClosestNPoints_24(id0,id1,id2,id3,id4); }

  private native void FindPointsWithinRadius_25(double id0,double id1,double id2,double id3,vtkIdList id4);
  public void FindPointsWithinRadius(double id0,double id1,double id2,double id3,vtkIdList id4)
    { FindPointsWithinRadius_25(id0,id1,id2,id3,id4); }

  public vtkStaticPointLocator() { super(); }

  public vtkStaticPointLocator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkStaticPointLocator.java <==
// java wrapper for vtkStaticPointLocator object
//

package vtk;
import vtk.*;

public class vtkStaticPointLocator extends vtkAbstractPointLocator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPointsPerBucket_2(int id0);
  public void SetNumberOfPointsPerBucket(int id0)
    { SetNumberOfPointsPerBucket_2(id0); }

  private native int GetNumberOfPointsPerBucketMinValue_3();
  public int GetNumberOfPointsPerBucketMinValue()
    { return GetNumberOfPointsPerBucketMinValue_3(); }

  private native int GetNumberOfPointsPerBucketMaxValue_4();
  public int GetNumberOfPointsPerBucketMaxValue()
    { return GetNumberOfPointsPerBucketMaxValue_4(); }

  private native int GetNumberOfPointsPerBucket_5();
  public int GetNumberOfPointsPerBucket()
    { return GetNumberOfPointsPerBucket_5(); }

  private native void SetDivisions_6(int id0,int id1,int id2);
  public void SetDivisions(int id0,int id1,int id2)
    { SetDivisions_6(id0,id1,id2); }

  private native void SetDivisions_7(int id0[]);
  public void SetDivisions(int id0[])
    { SetDivisions_7(id0); }

  private native int[]  GetDivisions_8();
  public int[]  GetDivisions()
    { return GetDivisions_8(); }

  private native int FindClosestPoint_9(double id0[]);
  public int FindClosestPoint(double id0[])
    { return FindClosestPoint_9(id0); }

  private native void FindClosestNPoints_10(int id0,double id1[],vtkIdList id2);
  public void FindClosestNPoints(int id0,double id1[],vtkIdList id2)
    { FindClosestNPoints_10(id0,id1,id2); }

  private native void FindPointsWithinRadius_11(double id0,double id1[],vtkIdList id2);
  public void FindPointsWithinRadius(double id0,double id1[],vtkIdList id2)
    { FindPointsWithinRadius_11(id0,id1,id2); }

  private native void Initialize_12();
  public void Initialize()
    { Initialize_12(); }

  private native void FreeSearchStructure_13();
  public void FreeSearchStructure()
    { FreeSearchStructure_13(); }

  private native void BuildLocator_14();
  public void BuildLocator()
    { BuildLocator_14(); }

  private native void GenerateRepresentation_15(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_15(id0,id1); }

  private native int GetNumberOfPointsInBucket_16(int id0);
  public int GetNumberOfPointsInBucket(int id0)
    { return GetNumberOfPointsInBucket_16(id0); }

  private native void GetBucketIds_17(int id0,vtkIdList id1);
  public void GetBucketIds(int id0,vtkIdList id1)
    { GetBucketIds_17(id0,id1); }

  private native void SetMaxNumberOfBuckets_18(int id0);
  public void SetMaxNumberOfBuckets(int id0)
    { SetMaxNumberOfBuckets_18(id0); }

  private native int GetMaxNumberOfBucketsMinValue_19();
  public int GetMaxNumberOfBucketsMinValue()
    { return GetMaxNumberOfBucketsMinValue_19(); }

  private native int GetMaxNumberOfBucketsMaxValue_20();
  public int GetMaxNumberOfBucketsMaxValue()
    { return GetMaxNumberOfBucketsMaxValue_20(); }

  private native int GetMaxNumberOfBuckets_21();
  public int GetMaxNumberOfBuckets()
    { return GetMaxNumberOfBuckets_21(); }

  private native boolean GetLargeIds_22();
  public boolean GetLargeIds()
    { return GetLargeIds_22(); }

  private native void GetSpacing_23(double id0[]);
  public void GetSpacing(double id0[])
    { GetSpacing_23(id0); }

  private native int FindClosestPoint_24(double id0,double id1,double id2);
  public int FindClosestPoint(double id0,double id1,double id2)
    { return FindClosestPoint_24(id0,id1,id2); }

  private native void FindClosestNPoints_25(int id0,double id1,double id2,double id3,vtkIdList id4);
  public void FindClosestNPoints(int id0,double id1,double id2,double id3,vtkIdList id4)
    { FindClosestNPoints_25(id0,id1,id2,id3,id4); }

  private native void FindPointsWithinRadius_26(double id0,double id1,double id2,double id3,vtkIdList id4);
  public void FindPointsWithinRadius(double id0,double id1,double id2,double id3,vtkIdList id4)
    { FindPointsWithinRadius_26(id0,id1,id2,id3,id4); }

  public vtkStaticPointLocator() { super(); }

  public vtkStaticPointLocator(long id) { super(id); }
  public native long   VTKInit();

}
